jenkins-bot has submitted this change and it was merged. ( 
https://gerrit.wikimedia.org/r/370102 )

Change subject: Fix apihelp example message
......................................................................


Fix apihelp example message

It should contain a helpful text, not the result of the query.

Change-Id: I85e0f5a5b7ccb49d91828b070434ef17796eecbe
---
M ApiDebugTemplates.php
M i18n/en.json
2 files changed, 3 insertions(+), 3 deletions(-)

Approvals:
  jenkins-bot: Verified
  Nikerabbit: Looks good to me, approved



diff --git a/i18n/en.json b/i18n/en.json
index 54e58b4..544ff7e 100644
--- a/i18n/en.json
+++ b/i18n/en.json
@@ -44,7 +44,7 @@
        "debugtemplates-output": "Debugging pane",
        "apihelp-expandframe-description": "Expand templates and parameters in 
wikitext assuming a specific frame context.",
        "apihelp-expandframe-summary": "Expand templates and parameters in 
wikitext assuming a specific frame context.",
-       "apihelp-expandframe-example-1": "{\"expandframe\":{\"result\":\"b\"}}",
+       "apihelp-expandframe-example-1": "Parse wikitext 
<kbd><nowiki>{{{a}}}</nowiki></kbd> with defined frame context.",
        "apihelp-expandframe-param-text": "The wikitext to expand.",
        "apihelp-expandframe-param-frame": "The frame context as a JSON-encoded 
map between parameter names and values.",
        "apihelp-expandframe-param-title": "A page title for context."

diff --git a/ApiDebugTemplates.php b/ApiDebugTemplates.php
index b847898..deac871 100644
--- a/ApiDebugTemplates.php
+++ b/ApiDebugTemplates.php
@@ -64,11 +64,11 @@
        /**
         * Provide an example of usage
         *
         * @return object Array showing an example use and its result
         */
        public function getExamplesMessages() {
                return array(
-                       
'action=expandframe&text={{{a}}}&frame={"a":"b"}&format=json'
+                       'action=expandframe&text={{{a}}}&frame={"a":"b"}'
                        => 'apihelp-expandframe-example-1'
                );
        }
@@ -64,11 +64,11 @@
         * Provide an example of usage
         *
-        * @return object Array showing an example use and its result
+        * @return object Array showing an example use and help text
         */
        public function getExamplesMessages() {
-- 
To view, visit https://gerrit.wikimedia.org/r/370102
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I85e0f5a5b7ccb49d91828b070434ef17796eecbe
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/DebugTemplates
Gerrit-Branch: master
Gerrit-Owner: Umherirrender <umherirrender_de...@web.de>
Gerrit-Reviewer: Anomie <bjor...@wikimedia.org>
Gerrit-Reviewer: Nikerabbit <niklas.laxst...@gmail.com>
Gerrit-Reviewer: Raimond Spekking <raimond.spekk...@gmail.com>
Gerrit-Reviewer: Siebrand <siebr...@kitano.nl>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to